#!/bin/bash
#
#	check_packages.sh check the necessary packages.
#	check_packages.sh Version: 1.04 (2017/04/07)
#

RPMDIR=""
LISTFILE=""
NGPKGLIST=""
NGFLAG="0"
TEMPDIR="temp"
ARCHLTH=40
PACLTH=50
LOGFILE="$0.log"
ALLSUCCESSFLAG="1"

usage()
{
	echo "Usage: $0 [-i directory]"
	echo "-i directory   Install necessary packages those are not installed."
	echo "               Directory is rpm packages's directory."
	exit 0
}

check_listfile()
{
	if /bin/uname -r 2>/dev/null|/bin/grep "2\\.6\\.32-696\\..*el6" >/dev/null 2>&1 ; then
		MACHARCH="`/bin/uname -m 2>/dev/null`"
		case "$MACHARCH" in
			i?86)
				LISTFILE="packages/RHEL6.9_x86.txt"
				;;
			x86_64)
				LISTFILE="packages/RHEL6.9_x86_64.txt"
				;;
			*)
				/bin/echo "ERROR: This architecture is not supported. So exit."
				exit 1
				;;
		esac
	elif /bin/uname -r 2>/dev/null|/bin/grep "2\\.6\\.32-.*el6" >/dev/null 2>&1 ; then
		MACHARCH="`/bin/uname -m 2>/dev/null`"
		case "$MACHARCH" in
			i?86)
				LISTFILE="packages/RHEL6_x86.txt"
				;;
			x86_64)
				LISTFILE="packages/RHEL6_x86_64.txt"
				;;
			*)
				/bin/echo "ERROR: This architecture is not supported. So exit."
				exit 1
				;;
		esac
	elif /bin/uname -r 2>/dev/null|/bin/grep "3\\.10\\.0-123\\..*el7" >/dev/null 2>&1 ; then 
		LISTFILE="packages/RHEL7.2orEarlier_x86_64.txt"
	elif /bin/uname -r 2>/dev/null|/bin/grep "3\\.10\\.0-229\\..*el7" >/dev/null 2>&1 ; then 
		LISTFILE="packages/RHEL7.2orEarlier_x86_64.txt"
	elif /bin/uname -r 2>/dev/null|/bin/grep "3\\.10\\.0-327\\..*el7" >/dev/null 2>&1 ; then 
		LISTFILE="packages/RHEL7.2orEarlier_x86_64.txt"
	elif /bin/uname -r 2>/dev/null|/bin/grep "4\\.1\\.12-.*el7uek" >/dev/null 2>&1 ; then
 		LISTFILE="packages/RHEL7.2orEarlier_x86_64.txt"
	elif /bin/uname -r 2>/dev/null|/bin/grep "3\\.10\\.0-.*el7" >/dev/null 2>&1 ; then 
		LISTFILE="packages/RHEL7_x86_64.txt"
	else
		/bin/echo "ERROR: This kernel is not supported. So exit."
		exit 1
	fi
	
	if ! [ -f "${LISTFILE}" ]; then
		/bin/echo "ERROR: The file ${LISTFILE} is not exist. So exit."
		exit 1
	fi
}

install_packages()
{
	cd ${TEMPDIR}
	PERLFLAG=0
	for i in `/bin/ls`
	{
		ISPERL=`/bin/echo ${i} | /bin/grep "^perl-"`
		if [ "${ISPERL}" == "" ]; then
			/bin/rpm -ivh "${i}" 2>>../${LOGFILE} 1>/dev/null
			if [ "$?" -ne "0" ] ; then
				/bin/echo "ERROR: Install ${i} failed, please confirm $0.log for detail information."
				ALLSUCCESSFLAG="0"
			fi
		elif [ "${PERLFLAG}" == "0" ]; then
			/bin/rpm -ivh perl* 2>>../${LOGFILE} 1>/dev/null
			if [ "$?" -ne "0" ] ; then
				/bin/echo "ERROR: Install perl packages failed, please confirm $0.log for detail information."
				ALLSUCCESSFLAG="0"
			fi
			PERLFLAG=1
		fi
	}
	cd ..
	/bin/rm -rf ${TEMPDIR} >/dev/null 2>&1
}

deal_packages()
{
	PKGNAME=""
	OPT=""
	ARCHPT=""
	ARCHIS=""
	RESULT=""
	GRP=""
	LASTGRP=""
	NGFLAG="0"

	OPT="'%{name}.%{arch}'"

	INSTFLAG=$1
	if [ "${INSTFLAG}" == "1" ]; then
		echo -e "\nThe package of [ NG ] will be installed."
	fi

	exec 3< "./$LISTFILE"
	while read GRP PKGNAME ARCHPT 0<&3
	do
		ARCHIS=`echo ${ARCHPT} | sed -e "s/(\(.*\))/\1/g;s/\\r//g"`
		RESULT=`rpm -q --qf ${OPT} ${PKGNAME} | grep ${ARCHIS}`

		if [ "${INSTFLAG}" == "0" ]; then
			if [ "$RESULT" != "" ]; then
				echo -en "${PKGNAME} \\033[${ARCHLTH}G(${ARCHIS}) \\033[${PACLTH}Gpackage [ OK ]\n"
			else
				echo -en "${PKGNAME} \\033[${ARCHLTH}G(${ARCHIS}) \\033[${PACLTH}Gpackage [ NG ]\n"
				NGFLAG="2"
			fi
		elif [ "$RESULT" == "" ]; then
			if ! [ -d "${RPMDIR}" ]; then
				echo -e "ERROR: Not found ${RPMDIR} directory."
				exit 1
			fi

			if ! [ "${GRP}" == "${LASTGRP}" ]; then
				if ! [ "${LASTGRP}" == "" ]; then
					install_packages
				fi

				LASTGRP=${GRP}
				/bin/mkdir ${TEMPDIR} >>${LOGFILE} 2>&1
			fi
				
			ISEXIST=`/bin/ls "${RPMDIR}" | /bin/grep "^${PKGNAME}-[0-9]" | /bin/grep ${ARCHIS} 2>/dev/null`
			if ! [ "${ISEXIST}" == "" ]; then
				/bin/cp -af "${RPMDIR}/${ISEXIST}" ${TEMPDIR} >>${LOGFILE} 2>&1
				if [ "$?" -ne "0" ] ; then
					ALLSUCCESSFLAG="0"
				fi
			else
				ALLSUCCESSFLAG="0"
				echo -e "ERROR: Not found ${RPMDIR}/${PKGNAME}-*.${ARCHIS}.rpm"
			fi
			
 		fi
	done
	exec 3<&-

	if [ "${INSTFLAG}" == "1" ]; then
		install_packages
	fi
}

while [ $# -gt "0" ] ; do
	case $1 in
		"-h")
			usage
			exit 0
			;;
		"-i")
			shift
			if [ $# -gt "0" -a "$1" != "-h" ] ; then
				RPMDIR="$1"
			else
				usage
				exit 1
			fi
			shift
			;;
		*)
			usage
			exit 1
			;;
	esac
done

check_listfile
deal_packages 0

if [ "${NGFLAG}" == "2" ]; then
	if ! [ "${RPMDIR}" == "" ]; then
		if [ -f "${LOGFILE}" ]; then
			/bin/rm -rf ${LOGFILE} >/dev/null 2>&1
		fi
		deal_packages 1
		if [ "${ALLSUCCESSFLAG}" == "1" ]; then
			echo "All packages are installed successfully."
		fi
	else
		echo -e "\nPlease install the package of [ NG ]."
	fi
fi

exit ${NGFLAG}
