#!/bin/bash
#
#  ESMPRO ServerAgentService
#    esmsas_openwsman_weekly.sh Version: 1.01 (2017/02/10)
#

# work mode: 1 - install; 2 - uninstall; other - invalid, show usage
WORKMODE="0"

# os version: 6 - RHEL 6.x; 7 - RHEL 7.x / OL7.2 UEKR4; other - not support
OSVERSION="0"

checkparam() {
	if [ "$1" = "-i" ] && [ "$2" = "" ]; then
		WORKMODE="1"
	elif [ "$1" = "-e" ] && [ "$2" = "" ]; then	
		WORKMODE="2"
	fi
}

checkkernel() {
	if /bin/uname -r 2>/dev/null|/bin/grep "2\\.6\\.32-.*el6" >/dev/null 2>&1 ; then
		OSVERSION="6"
	elif /bin/uname -r 2>/dev/null|/bin/grep "3\\.10\\.0-.*el7" >/dev/null 2>&1 ; then
		OSVERSION="7"
	elif /bin/uname -r 2>/dev/null|/bin/grep ".*el7uek" >/dev/null 2>&1 ; then
		OSVERSION="7"
	fi
}

install() {

	if [ -d "/opt/nec/esmpro_sa/tools" ] ; then
		/bin/rm -f 	/opt/nec/esmpro_sa/tools/esmsas_openwsman_weekly.sh >/dev/null 2>&1
		/bin/cp -a ./esmsas_openwsman_weekly.sh /opt/nec/esmpro_sa/tools/ >/dev/null 2>&1
	fi
	
	checkkernel
	
	if [ "$OSVERSION" = "6" ]; then
		/bin/rm -f /etc/cron.weekly/esmsas_openwsman_weekly.* >/dev/null 2>&1
		/bin/cp -a ./scripts/esmsas_openwsman_weekly.cron /etc/cron.weekly >/dev/null 2>&1
		
		
	elif [ "$OSVERSION" = "7" ]; then
		/bin/rm -f /usr/lib/systemd/system/esmsas_openwsman_weekly.* >/dev/null 2>&1
		/bin/cp -a ./scripts/esmsas_openwsman_weekly.timer /usr/lib/systemd/system >/dev/null 2>&1
		/bin/cp -a ./scripts/esmsas_openwsman_weekly.service /usr/lib/systemd/system >/dev/null 2>&1

		/usr/bin/systemctl enable esmsas_openwsman_weekly.timer
		/usr/bin/systemctl start esmsas_openwsman_weekly.timer
		
	else
		/bin/echo "Error: This OS is not supported!"
		exit 1
	fi
}

uninstall() {

	checkkernel
	
	if [ "$OSVERSION" = "6" ]; then
		/bin/rm -f /etc/cron.weekly/esmsas_openwsman_weekly.* >/dev/null 2>&1
		/bin/rm -f /opt/nec/esmpro_sa/tools/esmsas_openwsman_weekly.sh >/dev/null 2>&1
		
		
	elif [ "$OSVERSION" = "7" ]; then
		/usr/bin/systemctl stop esmsas_openwsman_weekly.timer
		/usr/bin/systemctl disable esmsas_openwsman_weekly.timer

		/bin/rm -f /usr/lib/systemd/system/esmsas_openwsman_weekly.* >/dev/null 2>&1
		/bin/rm -f /opt/nec/esmpro_sa/tools/esmsas_openwsman_weekly.sh >/dev/null 2>&1
		
	else
		/bin/echo "Error: This OS is not supported!"
		exit 1
	fi
}

showusage() {
	/bin/echo "Usage: $0 -i|-e"
	/bin/echo "       -i  Install."
	/bin/echo "       -e  Uninstall."
	exit 1
}

# main process

checkparam $*

if [ "$WORKMODE" = "1" ]; then
	install
elif [ "$WORKMODE" = "2" ]; then
	uninstall
else
	showusage
fi

exit 0
