#!/bin/bash
#
#  ESMPRO Agent / ESMPRO ServerAgentService
#    execEZCLCT.sh Version: 1.02 (2016/11/04)
#

#####################################################################################
EZCLCT_MODE="ch"
PID=""
#RQ0604/FPL6605 in 20161104. line+2
EZCLCTSETFLAG="0"
SYSLOGFLAG="0"

####################################################################################
checkrunning() {
        local LPID 

	LPID=$1
	if [ -z "$LPID" ] || [ ! -d "/proc/$LPID" ]; then
		return 1
	fi

	return 0
}

#####################################################################################
killpid(){
	local LPID
	
	LPID=$1

	#stty echo maybe closed in execEZCLCT 
	#so open it again
	stty echo >/dev/null 2>&1

	if [ -z "$LPID" ]; then
		return 0
	fi


	if checkrunning $LPID;then
		/bin/kill -TERM $LPID >/dev/null 2>&1
		/bin/usleep 100000
		if checkrunning $LPID && /bin/sleep 1 &&
			checkrunning $LPID && /bin/sleep 10 &&
			checkrunning $LPID ;then
			/bin/kill -KILL $LPID >/dev/null 2>&1
			/bin/usleep 100000
			return 1
		fi
	fi

	return 0
}

#####################################################################################
execEZCLCT()
{
	EZCLCT_PATH="/etc/ezclct/ezclct_path"
	EZCLCT_DIR=""
	EZCLCT_TIMEFILE="ezclct_waittime"
	EZCLCT_FILE="ezclct.sh"
	EZCLCT_WAITTIME=1500
	EZCLCT_DOT_INTERVAL=30

	mkdir -p "$COLLECTSA_DIR/collectsa/ezclct"
	{
		#get the intall path
		if [ ! -f "$EZCLCT_PATH" ] ; then
			echo "Ez-clct: path file not exist ($EZCLCT_PATH). ignore Ez-clct."
			return 1
		fi
		echo "Ez-clct: path file exist ($EZCLCT_PATH)."

		EZCLCT_DIR=`cat $EZCLCT_PATH 2>/dev/null`
		if [ -z "$EZCLCT_DIR" ] || [ ! -d "$EZCLCT_DIR" ]; then
			echo "Ez-clct: install dir not exist ($EZCLCT_DIR). ignore Ez-clct." 
			return 2
		fi
		echo "Ez-clct: install dir exist ($EZCLCT_DIR)." 

		#get the timeout
		if [ -f "$EZCLCT_DIR/$EZCLCT_TIMEFILE" ] ; then
			TMPWAITTIME=`cat "$EZCLCT_DIR/$EZCLCT_TIMEFILE" 2>/dev/null`
			echo "Ez-clct: time in $EZCLCT_DIR/$EZCLCT_TIMEFILE is $TMPWAITTIME"
			EZCLCT_WAITTIME=`echo $TMPWAITTIME | awk -v AWKWAITTIME=$EZCLCT_WAITTIME '{ if(NR==1) { print($0~/^[0-9]+$/)?$0:AWKWAITTIME}}'`
		else 
			echo "Ez-clct: no timeout file ($EZCLCT_DIR/$EZCLCT_TIMEFILE) default value is $EZCLCT_WAITTIME seconds"
		fi
		echo "Ez-clct: WAITTIME is set to $EZCLCT_WAITTIME" 

		if [ ! -f "$EZCLCT_DIR/$EZCLCT_FILE" ]; then
			echo "Ez-clct: file not exist ($EZCLCT_DIR/$EZCLCT_FILE). ignore Ez-clct."
			return 2
		fi

		#run the tool background 
		echo "Ez-clct: $EZCLCT_DIR/$EZCLCT_FILE $EZCLCT_MODE $COLLECTSA_DIR/collectsa/ezclct"
		echo "Ez-clct: begin:" `/bin/date`

		/bin/sh "$EZCLCT_DIR/$EZCLCT_FILE" $EZCLCT_MODE "$COLLECTSA_DIR/collectsa/ezclct" &  
	} > "$COLLECTSA_DIR/collectsa/ezclct/saezclct.log"  2>&1

		#get the pid of tool
		PID=$!

		waittime=0
		interval=1
		stoped=0
		stty -echo >/dev/null 2>&1
		while [ $waittime -lt $EZCLCT_WAITTIME ]; do
			let "PRINT_DOT = $waittime % $EZCLCT_DOT_INTERVAL"
			if [ "$PRINT_DOT" = "0" ]; then
				echo -ne "."
			fi
				
			/bin/sleep $interval
			
			if ! checkrunning $PID; then
				stoped=1
				break
			fi

			let "waittime += $interval"
		done
		echo -ne '\n'
		stty echo >/dev/null 2>&1

	{
		NEEDWAIT="1"
		if [ $stoped -ne 1 ]; then
			echo "Ez-clct: timeout($EZCLCT_WAITTIME) , kill the pid $PID"
			killpid $PID 
			ret=$?
			if [ $ret != 0 ]; then
				NEEDWAIT="0"	
			fi
		fi
	
		if [ $NEEDWAIT = "1" ]; then
			wait $PID
			ret=$?
		else
			ret="unknown (kill Ez-clct process $PID)"
		fi
		echo "Ez-clct: $EZCLCT_DIR/$EZCLCT_FILE finished. return value : $ret"
		echo "Ez-clct: end:" `/bin/date`

		PID=""
	} >> "$COLLECTSA_DIR/collectsa/ezclct/saezclct.log"  2>&1
	return 0	
}

#####################################################################################
cleanup()
{
	#kill the sub process PID when some signals is get
	killpid $PID; PID=""
}
#####################################################################################

if [ $UID != 0 ] ; then
        /bin/echo -e "\nThis program could be executed by root Only.\n"
        exit 2
fi

/bin/rm -rf collectsa 2>/dev/null 
/bin/rm -rf collectsa.tgz 2>/dev/null

COLLECTSA_DIR=`pwd` 

/bin/mkdir ./collectsa 
/bin/cp -af "${0}" ./collectsa/ 2>/dev/null

/bin/echo "$0 $@" > "$COLLECTSA_DIR/collectsa/execEZCLCT.log"
/bin/date >> "$COLLECTSA_DIR/collectsa/execEZCLCT.log"

#####################################################################################
				##################
				#Get option
				##################

#modify begin RQ0604/FPL6605 in 20161104.
#if [ "$1" != "" ] ; then
#	EZCLCT_MODE="$1"
#else
#	echo "Ez-clct: use default mode:$EZCLCT_MODE" >> "$COLLECTSA_DIR/collectsa/execEZCLCT.log"
#fi
while [ "$1" != "" ] ; do
	case $1 in
		"-s")
			SYSLOGFLAG="1"
			;;
		*)
			if [ "${EZCLCTSETFLAG}" = "0" ] ; then
				EZCLCT_MODE="$1"
				EZCLCTSETFLAG="1"
			fi
			;;
	esac
	shift
done
#modify end RQ0604/FPL6605 in 20161104.

####################################################################################

			###########################################
			#run Ez-clct tool                         #
			###########################################
		
#RQ0604/FPL6605 in 20161104. line+1
/bin/echo "Ez-clct mode : ${EZCLCT_MODE}" >> "$COLLECTSA_DIR/collectsa/execEZCLCT.log"

trap 'cleanup; exit 1' SIGTERM SIGINT SIGHUP SIGKILL
execEZCLCT

#modify begin RQ0604/FPL6605 in 20161104.
cd ./collectsa

####################################################################################

			#############################
			##  syslog & raidsrv's log ##
			#############################
if [ "${SYSLOGFLAG}" = "1" ] ; then

	#collect syslog.
	/bin/mkdir -p var/log
	cd var/log

	cd /var/log
	/bin/tar zcvf ./messages.tgz messages* 2>>"$COLLECTSA_DIR/collectsa/var/log/log.err" 1>/dev/null
	cd - &>/dev/null

	/bin/mv /var/log/messages.tgz ./ 2>>./log.err

	#collect raidsrv's log.
	/bin/mkdir raidsrv
	cd raidsrv

	if [ -d /var/log/raidsrv ] ; then
		/bin/cp -af /var/log/raidsrv/*.log ./ 2>/dev/null
	else
		/bin/echo "WARNING: get /var/log/raidsrv directory failed!" > ./raidsrv.err
	fi

	cd ../../..
fi

cd ..
#modify end RQ0604/FPL6605 in 20161104.

####################################################################################
retcode=0
/bin/tar czf collectsa.tgz collectsa 1>/dev/null 2>&1
if [ $? -ne 0 ] ; then
	retcode=1
fi
/bin/rm -rf collectsa 2>/dev/null
exit $retcode

